@@ -1,6 +1,5 @@
 from input_algorithms.errors import BadSpec, BadSpecValue, BadDirectory, BadFilename
 
-from option_merge import MergedOptions
 import operator
 import six
 import os
@@ -51,8 +50,8 @@ class dictionary_spec(Spec):
         return {}
 
     def normalise_filled(self, meta, val):
-        """Make sure it's a dictionary or MergedOptions"""
-        if not isinstance(val, dict) and not isinstance(val, MergedOptions):
+        """Make sure it's a dictionary"""
+        if not isinstance(val, dict):
             raise BadSpecValue("Expected a dictionary", meta=meta, got=type(val))
 
         return val
@@ -134,7 +133,7 @@ class set_options(Spec):
 
     def normalise_filled(self, meta, val):
         """Fill out a dictionary with what we want as well as the remaining extra"""
-        if not isinstance(val, dict) and not isinstance(val, MergedOptions):
+        if not isinstance(val, dict):
             raise BadSpecValue("Expected a dictionary", meta=meta, got=type(val))
 
         result = val
@@ -144,7 +143,9 @@ class set_options(Spec):
             val = result.get(key, NotSpecified)
 
             try:
-                result[key] = spec.normalise(meta.at(key), val)
+                normalised = spec.normalise(meta.at(key), val)
+                if normalised is not val:
+                    result[key] = spec.normalise(meta.at(key), val)
             except BadSpec as error:
                 errors.append(error)
 
